@@ -140,8 +140,10 @@ public:
   {
     prepareStatement();
     ODBCParam p;
+    // NOLINTBEGIN(cppcoreguidelines-owning-memory)
     p.ParameterValuePtr = new UDWORD{value};
     p.LenPtr = new SQLLEN{sizeof(UDWORD)};
+    // NOLINTEND(cppcoreguidelines-owning-memory)
     p.ParameterType = SQL_INTEGER;
     p.ValueType = SQL_INTEGER;
     return bind(name, p);
@@ -151,8 +153,10 @@ public:
   {
     prepareStatement();
     ODBCParam p;
+    // NOLINTBEGIN(cppcoreguidelines-owning-memory)
     p.ParameterValuePtr = new ULONG{value};
     p.LenPtr = new SQLLEN{sizeof(ULONG)};
+    // NOLINTEND(cppcoreguidelines-owning-memory)
     p.ParameterType = SQL_INTEGER;
     p.ValueType = SQL_INTEGER;
     return bind(name, p);
@@ -162,8 +166,10 @@ public:
   {
     prepareStatement();
     ODBCParam p;
+    // NOLINTBEGIN(cppcoreguidelines-owning-memory)
     p.ParameterValuePtr = new unsigned long long{value};
     p.LenPtr = new SQLLEN{sizeof(unsigned long long)};
+    // NOLINTEND(cppcoreguidelines-owning-memory)
     p.ParameterType = SQL_BIGINT;
     p.ValueType = SQL_C_UBIGINT;
     return bind(name, p);
@@ -179,11 +185,12 @@ public:
     prepareStatement();
     ODBCParam p;
 
+    // NOLINTBEGIN(cppcoreguidelines-owning-memory)
     p.ParameterValuePtr = (char*)new char[value.size() + 1];
     value.copy((char*)p.ParameterValuePtr, value.size());
     ((char*)p.ParameterValuePtr)[value.size()] = 0;
-    p.LenPtr = new SQLLEN;
-    *(p.LenPtr) = value.size();
+    p.LenPtr = new SQLLEN{static_cast<SQLLEN>(value.size())};
+    // NOLINTEND(cppcoreguidelines-owning-memory)
     p.ParameterType = SQL_VARCHAR;
     p.ValueType = SQL_C_CHAR;
 
@@ -199,8 +206,9 @@ public:
     ODBCParam p;
 
     p.ParameterValuePtr = NULL;
-    p.LenPtr = new SQLLEN;
-    *(p.LenPtr) = SQL_NULL_DATA;
+    // NOLINTBEGIN(cppcoreguidelines-owning-memory)
+    p.LenPtr = new SQLLEN{SQL_NULL_DATA};
+    // NOLINTEND(cppcoreguidelines-owning-memory)
     p.ParameterType = SQL_VARCHAR;
     p.ValueType = SQL_C_CHAR;
 
@@ -262,12 +270,23 @@ public:
     SQLCloseCursor(d_statement); // hack, this probably violates some state transitions
 
     for (auto& i : d_req_bind) {
-      if (i.ParameterType == SQL_VARCHAR)
-        delete[](char*) i.ParameterValuePtr;
-      else if (i.ParameterType == SQL_INTEGER)
-        delete (ULONG*)i.ParameterValuePtr;
-      else if (i.ParameterType == SQL_C_UBIGINT)
-        delete (unsigned long long*)i.ParameterValuePtr;
+      // NOLINTBEGIN(cppcoreguidelines-owning-memory)
+      if (i.ParameterType == SQL_VARCHAR) {
+        delete[] static_cast<char*>(i.ParameterValuePtr);
+      }
+      else if (i.ParameterType == SQL_INTEGER) {
+        if (*i.LenPtr == sizeof(UDWORD)) {
+          delete static_cast<UDWORD*>(i.ParameterValuePtr);
+        }
+        else {
+          delete static_cast<ULONG*>(i.ParameterValuePtr);
+        }
+      }
+      else if (i.ParameterType == SQL_C_UBIGINT) {
+        delete static_cast<unsigned long long*>(i.ParameterValuePtr);
+      }
+      // NOLINTEND(cppcoreguidelines-owning-memory)
+
       delete i.LenPtr;
     }
     d_req_bind.clear();
